#!/usr/bin/env python
# -*- coding: utf-8 -*-

PATH_SRC="29"
PATH_TMP="tmp"
PATH_TMP_UNZIP="tmp/unzip"
PATH_TMP_UNTAR="tmp/untar"
PATH_MIF="tmp/mif"
PATH_OUT="mif"


import sys,os,zipfile,tarfile,shutil,logging
logging.basicConfig(format='[%(levelname)s] %(message)s', level=logging.DEBUG)

try:
    PATH_SRC=sys.argv[1]
    PATH_OUT=sys.argv[2]
except:
    print """
usage   : python %s src_dir dst_dir
exemple : python %s pci mif
    """%(sys.argv[0],sys.argv[0])

def emptyDir(dirn):
    '''Purge a directory content'''
    files = os.listdir(dirn)
    for fn in files:
        path = os.path.join (dirn, fn)
        if os.path.isdir(path):
            emptyDir(path)
        else:
            retval = os.unlink(path)

def dirEntries(dir_name, subdir, *args):
    '''Return a list of file names found in directory 'dir_name'
    If 'subdir' is True, recursively access subdirectories under 'dir_name'.
    Additional arguments, if any, are file extensions to match filenames. Matched
        file names are added to the list.
    If there are no additional arguments, all files found in the directory are
        added to the list.
    Example usage: fileList = dirEntries(r'H:\TEMP', False, 'txt', 'py')
        Only files with 'txt' and 'py' extensions will be added to the list.
    Example usage: fileList = dirEntries(r'H:\TEMP', True)
        All files and all the files in subdirectories under H:\TEMP will be added
        to the list.
    '''
    fileList = []
    for file in os.listdir(dir_name):
        dirfile = os.path.join(dir_name, file)
        if os.path.isfile(dirfile):
            if not args:
                fileList.append(dirfile)
            else:
                if os.path.splitext(dirfile)[1][1:] in args:
                    fileList.append(dirfile)
        # recursively access file names in subdirectories
        elif os.path.isdir(dirfile) and subdir:
            fileList.extend(dirEntries(dirfile, subdir, *args))
    return fileList


def convertLot(srcPath):

    logging.info('checking %s'%srcPath)
    srcName=os.path.split(srcPath)[1]
    mifFilepath=os.path.join(PATH_OUT,srcName)

    # flag proceed
    proceed = False

    # is mif missing ?
    if not(os.path.isfile(mifFilepath)):
        logging.info('MIF not found, proceeding...')
        proceed=True

    # mif exists
    else:
        # is mif too old ?
        srcDate=os.path.getmtime(srcPath)
        mifDate=os.path.getmtime(mifFilepath)
        if srcDate>mifDate:
            logging.info('dataset %s is newer than MIF file, new convertion requested'%srcName)
            proceed=True
        else:
            logging.info('dataset %s is older than MIF file, skipping'%srcName)


    if proceed:

        # vidange repertoire tmp zip
        emptyDir(PATH_TMP_UNZIP)

        # decompression du lot
        logging.info('extracting %s into %s' % (srcPath,PATH_TMP_UNZIP))
        f=zipfile.ZipFile(srcPath,'r')
        f.extractall(PATH_TMP_UNZIP)
        f.close()

        # traitement des bz2
        emptyDir(PATH_TMP_UNTAR)
        fnbz2list=dirEntries(PATH_TMP_UNZIP,True,"bz2")
        logging.info('extracting %s bz2 files' % len(fnbz2list))
        for fnbz2 in fnbz2list:
            try:
               f=tarfile.open(fnbz2,'r:*')
               f.extractall(PATH_TMP_UNTAR)
               f.close()
            except:
               logging.error("%s/%s failed"%(srcName,fnbz2));

        # convertion edi2mif
        logging.info('converting %s files to mif format' % len(fnbz2list))
        os.system('perl edi2mif.pl %s %s 2>&1'%(PATH_TMP_UNTAR,PATH_MIF))
        logging.info(dirEntries(PATH_MIF,True))
        zipout=zipfile.ZipFile(mifFilepath,'w')
        for fnmif in dirEntries(PATH_MIF,False,"MIF","MID"):
            zipout.write(fnmif)
        zipout.close()





for fn in dirEntries(PATH_SRC,True,"zip","ZIP"):
    convertLot(fn)

